diff --git a/src/virsh.c b/src/virsh.c
--- a/src/virsh.c
+++ b/src/virsh.c
@@ -1662,6 +1662,7 @@ cmdSetmem(vshControl * ctl, vshCmd * cmd
 cmdSetmem(vshControl * ctl, vshCmd * cmd)
 {
     virDomainPtr dom;
+    virDomainInfo info;
     int kilobytes;
     int ret = TRUE;
 
@@ -1678,6 +1679,18 @@ cmdSetmem(vshControl * ctl, vshCmd * cmd
         return FALSE;
     }
 
+    if (virDomainGetInfo(dom, &info) != 0) {
+        virDomainFree(dom);
+        vshError(ctl, FALSE, _("Unable to verify MaxMemorySize"));
+        return FALSE;
+    }
+
+    if (kilobytes > info.maxMem) {
+        virDomainFree(dom);
+        vshError(ctl, FALSE, _("Invalid value of %d for memory size"), kilobytes);
+        return FALSE;
+    }
+
     if (virDomainSetMemory(dom, kilobytes) != 0) {
         ret = FALSE;
     }
@@ -1706,6 +1719,7 @@ cmdSetmaxmem(vshControl * ctl, vshCmd * 
 cmdSetmaxmem(vshControl * ctl, vshCmd * cmd)
 {
     virDomainPtr dom;
+    virDomainInfo info;
     int kilobytes;
     int ret = TRUE;
 
@@ -1722,7 +1736,22 @@ cmdSetmaxmem(vshControl * ctl, vshCmd * 
         return FALSE;
     }
 
+    if (virDomainGetInfo(dom, &info) != 0) {
+        virDomainFree(dom);
+        vshError(ctl, FALSE, _("Unable to verify current MemorySize"));
+        return FALSE;
+    }
+
+    if (kilobytes < info.memory) {
+        if (virDomainSetMemory(dom, kilobytes) != 0) {
+            virDomainFree(dom);
+            vshError(ctl, FALSE, _("Unable to shrink current MemorySize"));
+            return FALSE;
+        }
+    }
+
     if (virDomainSetMaxMemory(dom, kilobytes) != 0) {
+        vshError(ctl, FALSE, _("Unable to change MaxMemorySize"));
         ret = FALSE;
     }
 
